@@ -5,7 +5,7 @@ import json
 import logging.config
 import os
 import requests
-
+import urllib.request
 from .version import __version__ as VERSION
 from cfde_submit import CONFIG, exc, globus_http, validation, bdbag_utils
 from packaging.version import parse as parse_version
@@ -24,9 +24,6 @@ class CfdeClient:
         """Create a CfdeClient.
 
         Keyword Arguments:
-            service_instance (str): The instance of the Globus Automate Flow
-                    and/or the DERIVA ingest Action Provider to use. Unless directed otherwise,
-                    this should be left to the default. **Default**: ``prod``.
             tokens (dict): A dict keyed by scope, of active Globus Tokens. token keys MUST be a
                     subset of self.scopes. Each token value must contain an additional dict, and
                     have an active "access_token". setting tokens=None will require .login() to
@@ -37,6 +34,8 @@ class CfdeClient:
         self.__remote_config = {}  # managed by property
         self.__tokens = {}
         self.__flow_client = None
+        self.__transfer_client = None
+        self.transfer_scope = CONFIG["TRANSFER_SCOPE"]
         self.local_config = fair_research_login.ConfigParserTokenStorage(
             filename=self.config_filename
         )
@@ -120,7 +119,8 @@ class CfdeClient:
 
     @property
     def scopes(self):
-        return CONFIG["ALL_SCOPES"] + [self.gcs_https_scope, self.flow_scope]
+        return CONFIG["ALL_SCOPES"] + [self.gcs_https_scope, self.flow_scope,
+                                       self.transfer_scope]
 
     @property
     def gcs_https_scope(self):
@@ -185,6 +185,16 @@ class CfdeClient:
         )
         return self.__flow_client
 
+    @property
+    def transfer_client(self):
+        if self.__transfer_client:
+            return self.__transfer_client
+
+        transfer_token = self.tokens[self.transfer_scope]['access_token']
+        self.__transfer_client = globus_sdk.TransferClient(
+            authorizer=globus_sdk.AccessTokenAuthorizer(transfer_token))
+        return self.__transfer_client
+
     @property
     def https_authorizer(self):
         """Get the https authorizer for downloading/uploading data from the GCS instance.
@@ -215,20 +225,27 @@ class CfdeClient:
                 raise exc.SubmissionsUnavailable(
                     "Submissions to nih-cfde.org are temporarily offline. Please check "
                     "with out administrators for further details.")
+
             # Verify user has permission to view Flow
             try:
                 flow_info = self.remote_config["FLOWS"][self.service_instance]
                 self.flow_client.get_flow(flow_info["flow_id"])
-            except globus_sdk.GlobusAPIError as e:
-                logger.debug(str(e))
-                if e.http_status == 405:
-                    raise exc.PermissionDenied(
-                                "Unable to view ingest Flow. Are you in the CFDE DERIVA "
-                                "Demo Globus Group? Check your membership or apply for access "
-                                "here: \nhttps://app.globus.org/groups/a437abe3-c9a4-11e9-b441-"
-                                "0efb3ba9a670/about")
-                else:
+            except (globus_sdk.GlobusAPIError, globus_sdk.exc.GlobusAPIError) as e:
+                logger.exception(e)
+                if e.http_status not in [404, 405]:
                     raise
+                error_message = ("Permission denied. Please use the 'Onboarding to the Submission "
+                                 "System' page at https://github.com/nih-cfde/published-documentati"
+                                 "on/wiki/Onboarding-to-the-CFDE-Portal-Submission-System to "
+                                 "change your permissions. Only users with the Submitter role can "
+                                 "push data to the submission system. If you have already "
+                                 "sent in a request for Submitter status, but are getting this "
+                                 "error, be sure that you fully accepted the Globus invitation to "
+                                 "your Submitter group. You will need to click the 'Click here to "
+                                 "apply for membership' text in the invitation message and follow "
+                                 "instructions there before doing a submission.")
+                raise exc.PermissionDenied(error_message)
+
             self.ready = True
             logger.info('Check PASSED, client is ready use flows.')
         except Exception:
@@ -237,11 +254,9 @@ class CfdeClient:
             if raise_exception is True:
                 raise
 
-    def start_deriva_flow(self, data_path, dcc_id, catalog_id=None,
-                          schema=None, server=None,
+    def start_deriva_flow(self, data_path, dcc_id, catalog_id=None, schema=None, server=None,
                           output_dir=None, delete_dir=False, handle_git_repos=True,
-                          dry_run=False, test_sub=False, verbose=False,
-                          force_http=False, **kwargs):
+                          dry_run=False, test_sub=False, globus=False, **kwargs):
         """Start the Globus Automate Flow to ingest CFDE data into DERIVA.
 
         Arguments:
@@ -280,14 +295,7 @@ class CfdeClient:
                     the submission will be inegsted into DERIVA and immediately deleted?
                     When True, the data wil not remain in DERIVA to be viewed and the
                     Flow will terminate before any curation step.
-            verbose (bool): Should intermediate status messages be printed out?
-                    Default False.
-
-        Keyword Arguments:
-            force_http (bool): Should the data be sent using HTTP instead of Globus Transfer,
-                    even if Globus Transfer is available? Because Globus Transfer is more
-                    robust than HTTP, it is highly recommended to leave this False.
-                    Default False.
+            globus (bool): Should the data be transferred using Globus Transfer? Default False.
 
         Other keyword arguments are passed directly to the ``make_bag()`` function of the
         BDBag API (see https://github.com/fair-research/bdbag for details).
@@ -303,6 +311,13 @@ class CfdeClient:
                                  "a schema.".format(schema, catalog_id))
             schema = catalogs[catalog_id]
 
+        # Verify the dcc is valid
+        if ':' not in dcc_id:
+            dcc_id = f"cfde_registry_dcc:{dcc_id}"
+        if not self.valid_dcc(dcc_id):
+            raise exc.InvalidInput("Error: The dcc you've specified is not valid. Please double "
+                                   "check the spelling and try again.")
+
         # Coerces the BDBag path to a .zip archive
         data_path = bdbag_utils.get_bag(
             data_path, output_dir=output_dir, delete_dir=delete_dir,
@@ -332,12 +347,35 @@ class CfdeClient:
         if server:
             flow_input["server"] = server
 
-        # If local EP exists (and not force_http), can use Transfer
-        # Local EP fetched now in case GCP started after Client creation
-        local_endpoint = globus_sdk.LocalGlobusConnectPersonal().endpoint_id
-        logger.debug(f'Local endpoint: {local_endpoint}')
-        if local_endpoint and not force_http:
-            logger.debug("Using local Globus Connect Personal Endpoint '{}'".format(local_endpoint))
+        # Transfer data via globus
+        if globus:
+            local_endpoint = globus_sdk.LocalGlobusConnectPersonal().endpoint_id
+            logger.debug(f'Local endpoint: {local_endpoint}')
+            if not local_endpoint:
+                raise exc.EndpointUnavailable("Globus Connect Personal installation not found. To "
+                                              "install, please visit "
+                                              "https://www.globus.org/globus-connect-personal")
+            try:
+                self.transfer_client.operation_ls(local_endpoint, path=os.path.dirname(data_path))
+                logger.debug("Successfully connected to Globus Connect Personal endpoint "
+                             f"'{local_endpoint}'")
+            except globus_sdk.exc.TransferAPIError as e:
+
+                # Unable to connect
+                if e.http_status == 502:
+                    raise exc.EndpointUnavailable(f"Unable to connect to local endpoint "
+                                                  f"'{local_endpoint}'. Please verify that Globus "
+                                                  "Connect Personal is running.")
+                # Forbidden
+                elif e.http_status == 403:
+                    raise exc.EndpointUnavailable(f"Unable to access '{data_path}' on local "
+                                                  f"endpoint '{local_endpoint}'. Please set the "
+                                                  "access preferences in Globus Connect Personal "
+                                                  "to permit access.")
+
+                else:
+                    raise exc.EndpointUnavailable(e.message)
+
             # Populate Transfer fields in Flow
             flow_input.update({
                 "source_endpoint_id": local_endpoint,
@@ -346,9 +384,10 @@ class CfdeClient:
                 "cfde_ep_url": flow_info["cfde_ep_url"],
                 "is_directory": False,
             })
-        # Otherwise, we must PUT the BDBag on the server
+
+        # Otherwise, HTTP PUT the BDBag on the server
         else:
-            logger.debug("GCP Not installed, uploading with HTTP PUT instead")
+            logger.debug("Uploading with HTTPS PUT")
             data_url = "{}{}".format(flow_info["cfde_ep_url"], dest_path)
             globus_http.upload(data_path, data_url, self.https_authorizer)
             flow_input.update({
@@ -499,3 +538,19 @@ class CfdeClient:
             }
         else:
             print(clean_status)
+
+    def valid_dcc(self, dcc):
+        """
+        Verify that a user specified dcc exists in the deriva registry
+        """
+        if self.__service_instance == "prod":
+            server = "app.nih-cfde.org"
+        elif self.__service_instance == "staging":
+            server = "app-staging.nih-cfde.org"
+        elif self.__service_instance == "dev":
+            server = "app-dev.nih-cfde.org"
+        url = f"https://{server}/ermrest/catalog/registry/entity/CFDE:dcc"
+        with urllib.request.urlopen(url) as page:
+            data = json.loads(page.read().decode())
+            dccs = [x['id'] for x in data]
+        return dcc in dccs
