@@ -11,8 +11,8 @@ class CfdeClientException(Exception):
     pass
 
 
-class ValidationException(CfdeClientException):
-    """Something didn't validate"""
+class EndpointUnavailable(CfdeClientException):
+    """Unable to view globus connect personal endpoint"""
     pass
 
 
@@ -20,16 +20,6 @@ class InvalidInput(CfdeClientException):
     """A dataset given to the client was not valid"""
 
 
-class RemoteConfigException(CfdeClientException):
-    """There was a problem with the catalog"""
-    pass
-
-
-class PermissionDenied(CfdeClientException):
-    """The user needs to be added to a Globus Group"""
-    pass
-
-
 class NotLoggedIn(CfdeClientException):
     """User is not logged in"""
     pass
@@ -40,5 +30,20 @@ class OutdatedVersion(CfdeClientException):
     pass
 
 
+class PermissionDenied(CfdeClientException):
+    """The user needs to be added to a Globus Group"""
+    pass
+
+
+class RemoteConfigException(CfdeClientException):
+    """There was a problem with the catalog"""
+    pass
+
+
 class SubmissionsUnavailable(CfdeClientException):
     pass
+
+
+class ValidationException(CfdeClientException):
+    """Something didn't validate"""
+    pass
