@@ -30,14 +30,14 @@ def cli():
               show_default=True)
 @click.option("--verbose", "-v", is_flag=True, default=False, show_default=True)
 @click.option("--server", default=None)
-@click.option("--force-http", is_flag=True, default=False)
+@click.option("--globus", is_flag=True, default=False)
 @click.option("--bag-kwargs-file", type=click.Path(exists=True), default=None)
 @click.option("--client-state-file", type=click.Path(exists=True), default=None)
-def run(data_path, dcc_id, catalog, schema, output_dir, delete_dir, ignore_git,
-        dry_run, test_submission, verbose, server, force_http,
-        bag_kwargs_file, client_state_file):
+def run(data_path, dcc_id, catalog, schema, output_dir, delete_dir, ignore_git, dry_run,
+        test_submission, verbose, server, globus, bag_kwargs_file, client_state_file):
     """Start the Globus Automate Flow to ingest CFDE data into DERIVA."""
 
+    # Set log levels
     if verbose:
         set_log_level("DEBUG")
     else:
@@ -45,6 +45,7 @@ def run(data_path, dcc_id, catalog, schema, output_dir, delete_dir, ignore_git,
         if log_level:
             set_log_level(log_level)
 
+    # Read state file
     if not client_state_file:
         client_state_file = DEFAULT_STATE_FILE
     try:
@@ -62,25 +63,29 @@ def run(data_path, dcc_id, catalog, schema, output_dir, delete_dir, ignore_git,
     else:
         bag_kwargs = {}
 
-    # Determine DCC ID to use
-    logger.debug("Determining DCC")
+    # Determine DCC ID
     # If user supplies DCC as option, will always use that
     # If supplied DCC is different from previously saved DCC, prompt to save,
-    #   unless user has not saved DCC or disabled the save prompt
+    # unless user has not saved DCC or disabled the save prompt
+    logger.debug("Determining DCC")
     state_dcc = state.get("dcc_id")
     never_save = state.get("never_save")
+
     if not never_save and dcc_id is not None and state_dcc is not None and state_dcc != dcc_id:
         logger.debug("Saved DCC '{}' mismatch with provided DCC '{}'".format(state_dcc, dcc_id))
-        save_dcc = yes_or_no(f'Would you like to save {dcc_id} as your default DCC ID (instead of'
-                             f'"{state_dcc}"?)')
-        if not save_dcc:
-            if (input("Would you like to disable this prompt permanently? y/n:").strip().lower()
-                    in ["y", "yes"]):
+        save_dcc = yes_or_no(f'Would you like to save {dcc_id} as your default DCC ID (instead of '
+                             f'"{state_dcc}")?')
+        if save_dcc:
+            state['dcc_id'] = dcc_id
+        else:
+            disable_prompt = yes_or_no("Would you like to disable this prompt permanently?")
+            if disable_prompt:
                 state["never_save_dcc"] = True
+
     elif dcc_id is None and state_dcc is not None:
         dcc_id = state_dcc
-        save_dcc = False
         print("Using saved DCC '{}'".format(dcc_id))
+
     elif dcc_id is None and state_dcc is None:
         logger.debug("No saved DCC ID found and no DCC provided")
         dcc_id = input("Please enter the CFDE identifier for your "
@@ -95,25 +100,22 @@ def run(data_path, dcc_id, catalog, schema, output_dir, delete_dir, ignore_git,
         cfde = CfdeClient()
         login_user()
         logger.debug("CfdeClient initialized, starting Flow")
-        resp = yes_or_no(f"Submit datapackage '{os.path.basename(data_path)}' using {dcc_id}?")
+        package_name = os.path.basename(os.path.normpath(data_path))
+        resp = yes_or_no(f"Submit datapackage '{package_name}' using {dcc_id}?")
         if resp:
             start_res = cfde.start_deriva_flow(data_path, dcc_id=dcc_id, catalog_id=catalog,
-                                               schema=schema,
-                                               output_dir=output_dir, delete_dir=delete_dir,
-                                               handle_git_repos=(not ignore_git),
-                                               server=server, dry_run=dry_run,
-                                               test_sub=test_submission, verbose=verbose,
-                                               force_http=force_http, **bag_kwargs)
+                                               schema=schema, output_dir=output_dir,
+                                               delete_dir=delete_dir,
+                                               handle_git_repos=(not ignore_git), server=server,
+                                               dry_run=dry_run, test_sub=test_submission,
+                                               globus=globus, **bag_kwargs)
         else:
-            click.secho("Aborted. No data submitted.", fg="yellow")
-            return
-    except (exc.SubmissionsUnavailable, exc.InvalidInput, exc.ValidationException) as e:
-        click.secho(str(e), fg='red')
-        return
+            exit_on_exception("Aborted. No data submitted.")
+    except (exc.SubmissionsUnavailable, exc.InvalidInput, exc.ValidationException,
+            exc.EndpointUnavailable, FileExistsError) as e:
+        exit_on_exception(e)
     except Exception as e:
-        logger.exception(e)
-        print("Error while starting Flow: {}".format(repr(e)))
-        return
+        exit_on_exception(repr(e))
     else:
         if not start_res["success"]:
             print("Error during Flow startup: {}".format(start_res["error"]))
@@ -137,7 +139,7 @@ def run(data_path, dcc_id, catalog, schema, output_dir, delete_dir, ignore_git,
 @click.option("--client-state-file", type=click.Path(exists=True), default=None)
 def status(flow_id, flow_instance_id, raw, client_state_file):
     """Check the status of a Flow."""
-    login_user()
+    login_user(quiet=True)
     if not flow_id or not flow_instance_id:
         if not client_state_file:
             client_state_file = DEFAULT_STATE_FILE
@@ -170,15 +172,15 @@ def status(flow_id, flow_instance_id, raw, client_state_file):
             print(status_res["clean_status"])
 
 
-def login_user(force_login=False, no_browser=False, no_local_server=False):
+def login_user(force_login=False, no_browser=False, no_local_server=False, quiet=False):
     """
     Arguments:
         force_login -- Force a login flow with Globus Auth, even if tokens are valid
-        no_browser -- Disable automaically opening a browser for login
+        no_browser -- Disable automatically opening a browser for login
         no_local_server -- Disable local server for automatically copying auth code
     """
     cfde = CfdeClient()
-    if cfde.service_instance != "prod":
+    if not quiet and cfde.service_instance != "prod":
         click.secho(f"Running on service '{cfde.service_instance}'", fg="yellow")
 
     try:
@@ -187,7 +189,7 @@ def login_user(force_login=False, no_browser=False, no_local_server=False):
             click.secho("You are authenticated and your tokens have been cached.", fg='green')
         cfde.check()
     except exc.CfdeClientException as ce:
-        click.secho(str(ce), fg='red', err=True)
+        exit_on_exception(ce)
 
 
 @cli.command()
@@ -249,3 +251,8 @@ def yes_or_no(question):
     else:
         print("Please answer with 'y' or 'n'\n")
         return yes_or_no(question)
+
+
+def exit_on_exception(e):
+    """ Print an exception and exit with an error """
+    sys.exit(click.wrap_text(click.style(str(e), fg='red')))
